@@ -7,7 +7,7 @@ The Mandelbrot set rendering can be improved by using a normalized recount
 associated with a power normalized colormap (gamma=0.3). Rendering can be
 further enhanced thanks to shading.
 
-The `maxiter` gives the precision of the computation. `maxiter=200` should
+The ``maxiter`` gives the precision of the computation. ``maxiter=200`` should
 take a few seconds on most modern laptops.
 """
 import numpy as np
@@ -20,7 +20,7 @@ def mandelbrot_set(xmin, xmax, ymin, ymax, xn, yn, maxiter, horizon=2.0):
     N = np.zeros_like(C, dtype=int)
     Z = np.zeros_like(C)
     for n in range(maxiter):
-        I = np.less(abs(Z), horizon)
+        I = abs(Z) < horizon
         N[I] = n
         Z[I] = Z[I]**2 + C[I]
     N[N == maxiter-1] = 0
@@ -59,7 +59,7 @@ if __name__ == '__main__':
     light = colors.LightSource(azdeg=315, altdeg=10)
     M = light.shade(M, cmap=plt.cm.hot, vert_exag=1.5,
                     norm=colors.PowerNorm(0.3), blend_mode='hsv')
-    plt.imshow(M, extent=[xmin, xmax, ymin, ymax], interpolation="bicubic")
+    ax.imshow(M, extent=[xmin, xmax, ymin, ymax], interpolation="bicubic")
     ax.set_xticks([])
     ax.set_yticks([])
 
