@@ -1,112 +1,150 @@
-"""
+r"""
 This module contains functions to handle markers.  Used by both the
 marker functionality of `~matplotlib.axes.Axes.plot` and
 `~matplotlib.axes.Axes.scatter`.
 
 All possible markers are defined here:
 
-============================== ===============================================
-marker                         description
-============================== ===============================================
-`"."`                          point
-`","`                          pixel
-`"o"`                          circle
-`"v"`                          triangle_down
-`"^"`                          triangle_up
-`"<"`                          triangle_left
-`">"`                          triangle_right
-`"1"`                          tri_down
-`"2"`                          tri_up
-`"3"`                          tri_left
-`"4"`                          tri_right
-`"8"`                          octagon
-`"s"`                          square
-`"p"`                          pentagon
-`"P"`                          plus (filled)
-`"*"`                          star
-`"h"`                          hexagon1
-`"H"`                          hexagon2
-`"+"`                          plus
-`"x"`                          x
-`"X"`                          x (filled)
-`"D"`                          diamond
-`"d"`                          thin_diamond
-`"|"`                          vline
-`"_"`                          hline
-TICKLEFT                       tickleft
-TICKRIGHT                      tickright
-TICKUP                         tickup
-TICKDOWN                       tickdown
-CARETLEFT                      caretleft (centered at tip)
-CARETRIGHT                     caretright (centered at tip)
-CARETUP                        caretup (centered at tip)
-CARETDOWN                      caretdown (centered at tip)
-CARETLEFTBASE                  caretleft (centered at base)
-CARETRIGHTBASE                 caretright (centered at base)
-CARETUPBASE                    caretup (centered at base)
-`"None"`, `" "` or `""`        nothing
-``'$...$'``                    render the string using mathtext.
-`verts`                        a list of (x, y) pairs used for Path vertices.
-                               The center of the marker is located at (0,0) and
-                               the size is normalized.
-path                           a `~matplotlib.path.Path` instance.
-(`numsides`, `style`, `angle`) The marker can also be a tuple (`numsides`,
-                               `style`, `angle`), which will create a custom,
-                               regular symbol.
+============================== ====== =========================================
+marker                         symbol description
+============================== ====== =========================================
+``"."``                        |m00|  point
+``","``                        |m01|  pixel
+``"o"``                        |m02|  circle
+``"v"``                        |m03|  triangle_down
+``"^"``                        |m04|  triangle_up
+``"<"``                        |m05|  triangle_left
+``">"``                        |m06|  triangle_right
+``"1"``                        |m07|  tri_down
+``"2"``                        |m08|  tri_up
+``"3"``                        |m09|  tri_left
+``"4"``                        |m10|  tri_right
+``"8"``                        |m11|  octagon
+``"s"``                        |m12|  square
+``"p"``                        |m13|  pentagon
+``"P"``                        |m23|  plus (filled)
+``"*"``                        |m14|  star
+``"h"``                        |m15|  hexagon1
+``"H"``                        |m16|  hexagon2
+``"+"``                        |m17|  plus
+``"x"``                        |m18|  x
+``"X"``                        |m24|  x (filled)
+``"D"``                        |m19|  diamond
+``"d"``                        |m20|  thin_diamond
+``"|"``                        |m21|  vline
+``"_"``                        |m22|  hline
+``0`` (``TICKLEFT``)           |m25|  tickleft
+``1`` (``TICKRIGHT``)          |m26|  tickright
+``2`` (``TICKUP``)             |m27|  tickup
+``3`` (``TICKDOWN``)           |m28|  tickdown
+``4`` (``CARETLEFT``)          |m29|  caretleft
+``5`` (``CARETRIGHT``)         |m30|  caretright
+``6`` (``CARETUP``)            |m31|  caretup
+``7`` (``CARETDOWN``)          |m32|  caretdown
+``8`` (``CARETLEFTBASE``)      |m33|  caretleft (centered at base)
+``9`` (``CARETRIGHTBASE``)     |m34|  caretright (centered at base)
+``10`` (``CARETUPBASE``)       |m35|  caretup (centered at base)
+``11`` (``CARETDOWNBASE``)     |m36|  caretdown (centered at base)
+``"None"``, ``" "`` or  ``""``        nothing
+``'$...$'``                    |m37|  Render the string using mathtext.
+                                      E.g ``"$f$"`` for marker showing the
+                                      letter ``f``.
+``verts``                             A list of (x, y) pairs used for Path
+                                      vertices. The center of the marker is
+                                      located at (0, 0) and the size is
+                                      normalized, such that the created path
+                                      is encapsulated inside the unit cell.
+path                                  A `~matplotlib.path.Path` instance.
+``(numsides, 0, angle)``              A regular polygon with ``numsides``
+                                      sides, rotated by ``angle``.
+``(numsides, 1, angle)``              A star-like symbol with ``numsides``
+                                      sides, rotated by ``angle``.
+``(numsides, 2, angle)``              An asterisk with ``numsides`` sides,
+                                      rotated by ``angle``.
+============================== ====== =========================================
 
-                               `numsides`:
-                                   the number of sides
-
-                               `style`:
-                                   the style of the regular symbol:
-
-                                   0
-                                     a regular polygon
-                                   1
-                                     a star-like symbol
-                                   2
-                                     an asterisk
-                                   3
-                                     a circle (`numsides` and `angle` is
-                                     ignored)
-
-                               `angle`:
-                                   the angle of rotation of the symbol
-============================== ===============================================
-
-For backward compatibility, the form (`verts`, 0) is also accepted,
-but it is equivalent to just `verts` for giving a raw set of vertices
-that define the shape.
-
-`None` is the default which means 'nothing', however this table is
+``None`` is the default which means 'nothing', however this table is
 referred to from other docs for the valid inputs from marker inputs and in
-those cases `None` still means 'default'.
+those cases ``None`` still means 'default'.
+
+Note that special symbols can be defined via the
+:doc:`STIX math font </tutorials/text/mathtext>`,
+e.g. ``"$\u266B$"``. For an overview over the STIX font symbols refer to the
+`STIX font table <http://www.stixfonts.org/allGlyphs.html>`_.
+Also see the :doc:`/gallery/text_labels_and_annotations/stix_fonts_demo`.
+
+Integer numbers from ``0`` to ``11`` create lines and triangles. Those are
+equally accessible via capitalized variables, like ``CARETDOWNBASE``.
+Hence the following are equivalent::
+
+    plt.plot([1, 2, 3], marker=11)
+    plt.plot([1, 2, 3], marker=matplotlib.markers.CARETDOWNBASE)
+
+Examples showing the use of markers:
+
+* :doc:`/gallery/lines_bars_and_markers/marker_reference`
+* :doc:`/gallery/lines_bars_and_markers/marker_fillstyle_reference`
+* :doc:`/gallery/shapes_and_collections/marker_path`
+
+
+.. |m00| image:: /_static/markers/m00.png
+.. |m01| image:: /_static/markers/m01.png
+.. |m02| image:: /_static/markers/m02.png
+.. |m03| image:: /_static/markers/m03.png
+.. |m04| image:: /_static/markers/m04.png
+.. |m05| image:: /_static/markers/m05.png
+.. |m06| image:: /_static/markers/m06.png
+.. |m07| image:: /_static/markers/m07.png
+.. |m08| image:: /_static/markers/m08.png
+.. |m09| image:: /_static/markers/m09.png
+.. |m10| image:: /_static/markers/m10.png
+.. |m11| image:: /_static/markers/m11.png
+.. |m12| image:: /_static/markers/m12.png
+.. |m13| image:: /_static/markers/m13.png
+.. |m14| image:: /_static/markers/m14.png
+.. |m15| image:: /_static/markers/m15.png
+.. |m16| image:: /_static/markers/m16.png
+.. |m17| image:: /_static/markers/m17.png
+.. |m18| image:: /_static/markers/m18.png
+.. |m19| image:: /_static/markers/m19.png
+.. |m20| image:: /_static/markers/m20.png
+.. |m21| image:: /_static/markers/m21.png
+.. |m22| image:: /_static/markers/m22.png
+.. |m23| image:: /_static/markers/m23.png
+.. |m24| image:: /_static/markers/m24.png
+.. |m25| image:: /_static/markers/m25.png
+.. |m26| image:: /_static/markers/m26.png
+.. |m27| image:: /_static/markers/m27.png
+.. |m28| image:: /_static/markers/m28.png
+.. |m29| image:: /_static/markers/m29.png
+.. |m30| image:: /_static/markers/m30.png
+.. |m31| image:: /_static/markers/m31.png
+.. |m32| image:: /_static/markers/m32.png
+.. |m33| image:: /_static/markers/m33.png
+.. |m34| image:: /_static/markers/m34.png
+.. |m35| image:: /_static/markers/m35.png
+.. |m36| image:: /_static/markers/m36.png
+.. |m37| image:: /_static/markers/m37.png
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import six
-from six.moves import xrange
-
-from collections import Sized
+from collections.abc import Sized
+from numbers import Number
 
 import numpy as np
 
-from . import rcParams
-from .cbook import is_math_text, is_numlike
+from . import cbook, rcParams
 from .path import Path
 from .transforms import IdentityTransform, Affine2D
 
 # special-purpose marker identifiers:
 (TICKLEFT, TICKRIGHT, TICKUP, TICKDOWN,
  CARETLEFT, CARETRIGHT, CARETUP, CARETDOWN,
- CARETLEFTBASE, CARETRIGHTBASE, CARETUPBASE, CARETDOWNBASE) = xrange(12)
+ CARETLEFTBASE, CARETRIGHTBASE, CARETUPBASE, CARETDOWNBASE) = range(12)
 
 _empty_path = Path(np.empty((0, 2)))
 
 
-class MarkerStyle(object):
+class MarkerStyle:
 
     markers = {
         '.': 'point',
@@ -166,8 +204,6 @@ class MarkerStyle(object):
 
     def __init__(self, marker=None, fillstyle=None):
         """
-        MarkerStyle
-
         Attributes
         ----------
         markers : list of known marks
@@ -178,25 +214,16 @@ class MarkerStyle(object):
 
         Parameters
         ----------
-        marker : string or array_like, optional, default: None
+        marker : str or array-like, optional, default: None
             See the descriptions of possible markers in the module docstring.
 
-        fillstyle : string, optional, default: 'full'
+        fillstyle : str, optional, default: 'full'
             'full', 'left", 'right', 'bottom', 'top', 'none'
         """
         self._marker_function = None
         self.set_fillstyle(fillstyle)
         self.set_marker(marker)
 
-    def __getstate__(self):
-        d = self.__dict__.copy()
-        d.pop('_marker_function')
-        return d
-
-    def __setstate__(self, statedict):
-        self.__dict__ = statedict
-        self.set_marker(self._marker)
-
     def _recache(self):
         if self._marker_function is None:
             return
@@ -210,12 +237,8 @@ class MarkerStyle(object):
         self._filled = True
         self._marker_function()
 
-    if six.PY3:
-        def __bool__(self):
-            return bool(len(self._path.vertices))
-    else:
-        def __nonzero__(self):
-            return bool(len(self._path.vertices))
+    def __bool__(self):
+        return bool(len(self._path.vertices))
 
     def is_filled(self):
         return self._filled
@@ -233,9 +256,7 @@ class MarkerStyle(object):
         """
         if fillstyle is None:
             fillstyle = rcParams['markers.fillstyle']
-        if fillstyle not in self.fillstyles:
-            raise ValueError("Unrecognized fillstyle %s"
-                             % ' '.join(self.fillstyles))
+        cbook._check_in_list(self.fillstyles, fillstyle=fillstyle)
         self._fillstyle = fillstyle
         self._recache()
 
@@ -252,24 +273,24 @@ class MarkerStyle(object):
         if (isinstance(marker, np.ndarray) and marker.ndim == 2 and
                 marker.shape[1] == 2):
             self._marker_function = self._set_vertices
+        elif isinstance(marker, str) and cbook.is_math_text(marker):
+            self._marker_function = self._set_mathtext_path
+        elif isinstance(marker, Path):
+            self._marker_function = self._set_path_marker
         elif (isinstance(marker, Sized) and len(marker) in (2, 3) and
-                marker[1] in (0, 1, 2, 3)):
+                marker[1] in (0, 1, 2)):
             self._marker_function = self._set_tuple_marker
         elif (not isinstance(marker, (np.ndarray, list)) and
               marker in self.markers):
             self._marker_function = getattr(
                 self, '_set_' + self.markers[marker])
-        elif isinstance(marker, six.string_types) and is_math_text(marker):
-            self._marker_function = self._set_mathtext_path
-        elif isinstance(marker, Path):
-            self._marker_function = self._set_path_marker
         else:
             try:
                 Path(marker)
                 self._marker_function = self._set_vertices
             except ValueError:
-                raise ValueError('Unrecognized marker style'
-                                 ' {0}'.format(marker))
+                raise ValueError('Unrecognized marker style {!r}'
+                                 .format(marker))
 
         self._marker = marker
         self._recache()
@@ -309,29 +330,23 @@ class MarkerStyle(object):
 
     def _set_tuple_marker(self):
         marker = self._marker
-        if is_numlike(marker[0]):
-            if len(marker) == 2:
-                numsides, rotation = marker[0], 0.0
-            elif len(marker) == 3:
-                numsides, rotation = marker[0], marker[2]
-            symstyle = marker[1]
-            if symstyle == 0:
-                self._path = Path.unit_regular_polygon(numsides)
-                self._joinstyle = 'miter'
-            elif symstyle == 1:
-                self._path = Path.unit_regular_star(numsides)
-                self._joinstyle = 'bevel'
-            elif symstyle == 2:
-                self._path = Path.unit_regular_asterisk(numsides)
-                self._filled = False
-                self._joinstyle = 'bevel'
-            elif symstyle == 3:
-                self._path = Path.unit_circle()
-            self._transform = Affine2D().scale(0.5).rotate_deg(rotation)
+        if len(marker) == 2:
+            numsides, rotation = marker[0], 0.0
+        elif len(marker) == 3:
+            numsides, rotation = marker[0], marker[2]
+        symstyle = marker[1]
+        if symstyle == 0:
+            self._path = Path.unit_regular_polygon(numsides)
+            self._joinstyle = 'miter'
+        elif symstyle == 1:
+            self._path = Path.unit_regular_star(numsides)
+            self._joinstyle = 'bevel'
+        elif symstyle == 2:
+            self._path = Path.unit_regular_asterisk(numsides)
+            self._filled = False
+            self._joinstyle = 'bevel'
         else:
-            verts = np.asarray(marker[0])
-            path = Path(verts)
-            self._set_custom_marker(path)
+            raise ValueError(f"Unexpected tuple marker: {marker}")
 
     def _set_mathtext_path(self):
         """
@@ -344,10 +359,7 @@ class MarkerStyle(object):
 
         # again, the properties could be initialised just once outside
         # this function
-        # Font size is irrelevant here, it will be rescaled based on
-        # the drawn size later
-        props = FontProperties(size=1.0)
-        text = TextPath(xy=(0, 0), s=self.get_marker(), fontproperties=props,
+        text = TextPath(xy=(0, 0), s=self.get_marker(),
                         usetex=rcParams['text.usetex'])
         if len(text.vertices) == 0:
             return
@@ -364,9 +376,7 @@ class MarkerStyle(object):
         self._snap = False
 
     def _half_fill(self):
-        fs = self.get_fillstyle()
-        result = fs in self._half_fillstyles
-        return result
+        return self.get_fillstyle() in self._half_fillstyles
 
     def _set_circle(self, reduction=1.0):
         self._transform = Affine2D().scale(0.5 * reduction)
@@ -425,7 +435,7 @@ class MarkerStyle(object):
         [Path.MOVETO, Path.LINETO, Path.LINETO, Path.CLOSEPOLY])
 
     def _set_triangle(self, rot, skip):
-        self._transform = Affine2D().scale(0.5, 0.5).rotate_deg(rot)
+        self._transform = Affine2D().scale(0.5).rotate_deg(rot)
         self._snap_threshold = 5.0
         fs = self.get_fillstyle()
 
