@@ -1,46 +1,48 @@
-# -*- encoding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import os
+from pathlib import Path
 import shutil
+import subprocess
+from tempfile import TemporaryDirectory
 
 import numpy as np
 import pytest
+import platform
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
-from matplotlib.compat import subprocess
 from matplotlib.testing.compare import compare_images, ImageComparisonFailure
-from matplotlib.testing.decorators import _image_directories
+from matplotlib.testing.decorators import image_comparison, _image_directories
+from matplotlib.backends.backend_pgf import PdfPages
 
 baseline_dir, result_dir = _image_directories(lambda: 'dummy func')
 
 
 def check_for(texsystem):
-    header = """
-    \\documentclass{minimal}
-    \\usepackage{pgf}
-    \\begin{document}
-    \\typeout{pgfversion=\\pgfversion}
-    \\makeatletter
-    \\@@end
-    """
-    try:
-        latex = subprocess.Popen([str(texsystem), "-halt-on-error"],
-                                 stdin=subprocess.PIPE,
-                                 stdout=subprocess.PIPE)
-        stdout, stderr = latex.communicate(header.encode("utf8"))
-    except OSError:
-        return False
-
-    return latex.returncode == 0
+    with TemporaryDirectory() as tmpdir:
+        tex_path = Path(tmpdir, "test.tex")
+        tex_path.write_text(r"""
+            \documentclass{minimal}
+            \usepackage{pgf}
+            \begin{document}
+            \typeout{pgfversion=\pgfversion}
+            \makeatletter
+            \@@end
+        """)
+        try:
+            subprocess.check_call(
+                [texsystem, "-halt-on-error", str(tex_path)], cwd=tmpdir,
+                stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        except (OSError, subprocess.CalledProcessError):
+            return False
+        return True
 
 
 needs_xelatex = pytest.mark.skipif(not check_for('xelatex'),
                                    reason='xelatex + pgf is required')
 needs_pdflatex = pytest.mark.skipif(not check_for('pdflatex'),
                                     reason='pdflatex + pgf is required')
+needs_lualatex = pytest.mark.skipif(not check_for('lualatex'),
+                                    reason='lualatex + pgf is required')
 
 
 def compare_figure(fname, savefig_kwargs={}, tol=0):
@@ -82,22 +84,20 @@ def create_figure():
 
 # test compiling a figure to pdf with xelatex
 @needs_xelatex
-@pytest.mark.style('default')
 @pytest.mark.backend('pgf')
+@image_comparison(['pgf_xelatex.pdf'], style='default')
 def test_xelatex():
     rc_xelatex = {'font.family': 'serif',
                   'pgf.rcfonts': False}
     mpl.rcParams.update(rc_xelatex)
     create_figure()
-    compare_figure('pgf_xelatex.pdf', tol=0)
 
 
 # test compiling a figure to pdf with pdflatex
 @needs_pdflatex
-@pytest.mark.style('default')
 @pytest.mark.backend('pgf')
+@image_comparison(['pgf_pdflatex.pdf'], style='default')
 def test_pdflatex():
-    import os
     if os.environ.get('APPVEYOR', False):
         pytest.xfail("pdflatex test does not work on appveyor due to missing "
                      "LaTeX fonts")
@@ -109,7 +109,6 @@ def test_pdflatex():
                                     '\\usepackage[T1]{fontenc}']}
     mpl.rcParams.update(rc_pdflatex)
     create_figure()
-    compare_figure('pgf_pdflatex.pdf', tol=0)
 
 
 # test updating the rc parameters for each figure
@@ -118,30 +117,26 @@ def test_pdflatex():
 @pytest.mark.style('default')
 @pytest.mark.backend('pgf')
 def test_rcupdate():
-    rc_sets = []
-    rc_sets.append({'font.family': 'sans-serif',
-                    'font.size': 30,
-                    'figure.subplot.left': .2,
-                    'lines.markersize': 10,
-                    'pgf.rcfonts': False,
-                    'pgf.texsystem': 'xelatex'})
-    rc_sets.append({'font.family': 'monospace',
-                    'font.size': 10,
-                    'figure.subplot.left': .1,
-                    'lines.markersize': 20,
-                    'pgf.rcfonts': False,
-                    'pgf.texsystem': 'pdflatex',
-                    'pgf.preamble': ['\\usepackage[utf8x]{inputenc}',
-                                     '\\usepackage[T1]{fontenc}',
-                                     '\\usepackage{sfmath}']})
-    tol = (6, 0)
-    original_params = mpl.rcParams.copy()
+    rc_sets = [{'font.family': 'sans-serif',
+                'font.size': 30,
+                'figure.subplot.left': .2,
+                'lines.markersize': 10,
+                'pgf.rcfonts': False,
+                'pgf.texsystem': 'xelatex'},
+               {'font.family': 'monospace',
+                'font.size': 10,
+                'figure.subplot.left': .1,
+                'lines.markersize': 20,
+                'pgf.rcfonts': False,
+                'pgf.texsystem': 'pdflatex',
+                'pgf.preamble': ['\\usepackage[utf8x]{inputenc}',
+                                 '\\usepackage[T1]{fontenc}',
+                                 '\\usepackage{sfmath}']}]
+    tol = [6, 0]
     for i, rc_set in enumerate(rc_sets):
-        mpl.rcParams.clear()
-        mpl.rcParams.update(original_params)
-        mpl.rcParams.update(rc_set)
-        create_figure()
-        compare_figure('pgf_rcupdate%d.pdf' % (i + 1), tol=tol[i])
+        with mpl.rc_context(rc_set):
+            create_figure()
+            compare_figure('pgf_rcupdate%d.pdf' % (i + 1), tol=tol[i])
 
 
 # test backend-side clipping, since large numbers are not supported by TeX
@@ -163,8 +158,9 @@ def test_pathclip():
 
 # test mixed mode rendering
 @needs_xelatex
-@pytest.mark.style('default')
 @pytest.mark.backend('pgf')
+@image_comparison(['pgf_mixedmode.pdf'], style='default',
+                  tol={'aarch64': 1.086}.get(platform.machine(), 0.0))
 def test_mixedmode():
     rc_xelatex = {'font.family': 'serif',
                   'pgf.rcfonts': False}
@@ -173,7 +169,6 @@ def test_mixedmode():
     Y, X = np.ogrid[-1:1:40j, -1:1:40j]
     plt.figure()
     plt.pcolor(X**2 + Y**2).set_rasterized(True)
-    compare_figure('pgf_mixedmode.pdf', tol=0)
 
 
 # test bbox_inches clipping
@@ -196,3 +191,81 @@ def test_bbox_inches():
     bbox = ax1.get_window_extent().transformed(fig.dpi_scale_trans.inverted())
     compare_figure('pgf_bbox_inches.pdf', savefig_kwargs={'bbox_inches': bbox},
                    tol=0)
+
+
+@needs_pdflatex
+@pytest.mark.style('default')
+@pytest.mark.backend('pgf')
+def test_pdf_pages():
+    rc_pdflatex = {
+        'font.family': 'serif',
+        'pgf.rcfonts': False,
+        'pgf.texsystem': 'pdflatex',
+    }
+    mpl.rcParams.update(rc_pdflatex)
+
+    fig1 = plt.figure()
+    ax1 = fig1.add_subplot(1, 1, 1)
+    ax1.plot(range(5))
+    fig1.tight_layout()
+
+    fig2 = plt.figure(figsize=(3, 2))
+    ax2 = fig2.add_subplot(1, 1, 1)
+    ax2.plot(range(5))
+    fig2.tight_layout()
+
+    with PdfPages(os.path.join(result_dir, 'pdfpages.pdf')) as pdf:
+        pdf.savefig(fig1)
+        pdf.savefig(fig2)
+
+
+@needs_xelatex
+@pytest.mark.style('default')
+@pytest.mark.backend('pgf')
+def test_pdf_pages_metadata():
+    rc_pdflatex = {
+        'font.family': 'serif',
+        'pgf.rcfonts': False,
+        'pgf.texsystem': 'xelatex',
+    }
+    mpl.rcParams.update(rc_pdflatex)
+
+    fig = plt.figure()
+    ax = fig.add_subplot(1, 1, 1)
+    ax.plot(range(5))
+    fig.tight_layout()
+
+    md = {'author': 'me', 'title': 'Multipage PDF with pgf'}
+    path = os.path.join(result_dir, 'pdfpages_meta.pdf')
+
+    with PdfPages(path, metadata=md) as pdf:
+        pdf.savefig(fig)
+        pdf.savefig(fig)
+        pdf.savefig(fig)
+
+        assert pdf.get_pagecount() == 3
+
+
+@needs_lualatex
+@pytest.mark.style('default')
+@pytest.mark.backend('pgf')
+def test_pdf_pages_lualatex():
+    rc_pdflatex = {
+        'font.family': 'serif',
+        'pgf.rcfonts': False,
+        'pgf.texsystem': 'lualatex'
+    }
+    mpl.rcParams.update(rc_pdflatex)
+
+    fig = plt.figure()
+    ax = fig.add_subplot(1, 1, 1)
+    ax.plot(range(5))
+    fig.tight_layout()
+
+    md = {'author': 'me', 'title': 'Multipage PDF with pgf'}
+    path = os.path.join(result_dir, 'pdfpages_lua.pdf')
+    with PdfPages(path, metadata=md) as pdf:
+        pdf.savefig(fig)
+        pdf.savefig(fig)
+
+        assert pdf.get_pagecount() == 2
