@@ -1,4 +1,5 @@
 from io import BytesIO
+import multiprocessing
 import os
 from pathlib import Path
 import shutil
@@ -160,9 +161,9 @@ def test_user_fonts_linux(tmpdir, monkeypatch):
 @pytest.mark.skipif(sys.platform != 'win32', reason='Windows only')
 def test_user_fonts_win32():
     if not os.environ.get('APPVEYOR', False):
-        pytest.xfail('This test does only work on appveyor since user fonts '
-                     'are Windows specific and the developer\'s font '
-                     'directory should remain unchanged')
+        pytest.xfail("This test does only work on appveyor since user fonts "
+                     "are Windows specific and the developer's font directory "
+                     "should remain unchanged.")
 
     font_test_file = 'mpltest.ttf'
 
@@ -184,3 +185,18 @@ def test_user_fonts_win32():
     # Now, the font should be available
     fonts = findSystemFonts()
     assert any(font_test_file in font for font in fonts)
+
+
+def _model_handler(_):
+    fig, ax = plt.subplots()
+    fig.savefig(BytesIO(), format="pdf")
+    plt.close()
+
+
+@pytest.mark.skipif(not hasattr(os, "register_at_fork"),
+                    reason="Cannot register at_fork handlers")
+def test_fork():
+    _model_handler(0)  # Make sure the font cache is filled.
+    ctx = multiprocessing.get_context("fork")
+    with ctx.Pool(processes=2) as pool:
+        pool.map(_model_handler, range(2))
