@@ -55,7 +55,7 @@ math_tests = [
     '$\\alpha \\beta \\gamma \\delta \\epsilon \\zeta \\eta \\theta \\iota \\lambda \\mu \\nu \\xi \\pi \\kappa \\rho \\sigma \\tau \\upsilon \\phi \\chi \\psi$',
 
     # The examples prefixed by 'mmltt' are from the MathML torture test here:
-    # http://www.mozilla.org/projects/mathml/demo/texvsmml.xhtml
+    # https://developer.mozilla.org/en-US/docs/Mozilla/MathML_Project/MathML_Torture_Test
     r'${x}^{2}{y}^{2}$',
     r'${}_{2}F_{3}$',
     r'$\frac{x+{y}^{2}}{k+1}$',
@@ -75,7 +75,7 @@ math_tests = [
     # mathtex doesn't support array
     # 'mmltt18'    : r'$f\left(x\right)=\left\{\begin{array}{cc}\hfill 1/3\hfill & \text{if_}0\le x\le 1;\hfill \\ \hfill 2/3\hfill & \hfill \text{if_}3\le x\le 4;\hfill \\ \hfill 0\hfill & \text{elsewhere.}\hfill \end{array}$',
     # mathtex doesn't support stackrel
-    # 'mmltt19'    : ur'$\stackrel{\stackrel{k\text{times}}{\ufe37}}{x+...+x}$',
+    # 'mmltt19'    : r'$\stackrel{\stackrel{k\text{times}}{\ufe37}}{x+...+x}$',
     r'${y}_{{x}^{2}}$',
     # mathtex doesn't support the "\text" command
     # 'mmltt21'    : r'$\sum _{p\text{\prime}}f\left(p\right)={\int }_{t>1}f\left(t\right) d\pi \left(t\right)$',
@@ -145,15 +145,14 @@ font_test_specs = [
 
 font_tests = []
 for fonts, chars in font_test_specs:
-    wrapper = [' '.join(fonts), ' $']
-    for font in fonts:
-        wrapper.append(r'\%s{' % font)
-    wrapper.append('%s')
-    for font in fonts:
-        wrapper.append('}')
-    wrapper.append('$')
-    wrapper = ''.join(wrapper)
-
+    wrapper = ''.join([
+        ' '.join(fonts),
+        ' $',
+        *(r'\%s{' % font for font in fonts),
+        '%s',
+        *('}' for font in fonts),
+        '$',
+    ])
     for set in chars:
         font_tests.append(wrapper % set)
 
