@@ -1,17 +1,23 @@
 import pytest
+import platform
 
-import matplotlib
-from matplotlib.testing.decorators import image_comparison
+import matplotlib as mpl
+from matplotlib.testing.decorators import check_figures_equal, image_comparison
 import matplotlib.pyplot as plt
+from matplotlib.ticker import EngFormatter
+
+
+@pytest.fixture(autouse=True)  # All tests in this module use usetex.
+def usetex():
+    if not mpl.checkdep_usetex(True):
+        pytest.skip('Missing TeX of Ghostscript or dvipng')
+    mpl.rcParams['text.usetex'] = True
 
 
-@pytest.mark.skipif(not matplotlib.checkdep_usetex(True),
-                    reason='Missing TeX or Ghostscript or dvipng')
 @image_comparison(baseline_images=['test_usetex'],
                   extensions=['pdf', 'png'],
-                  tol=0.3)
+                  tol={'aarch64': 2.868}.get(platform.machine(), 0.3))
 def test_usetex():
-    matplotlib.rcParams['text.usetex'] = True
     fig = plt.figure()
     ax = fig.add_subplot(111)
     ax.text(0.1, 0.2,
@@ -23,3 +29,9 @@ def test_usetex():
             fontsize=24)
     ax.set_xticks([])
     ax.set_yticks([])
+
+
+@check_figures_equal()
+def test_unicode_minus(fig_test, fig_ref):
+    fig_test.text(.5, .5, "$-$")
+    fig_ref.text(.5, .5, "\N{MINUS SIGN}")
