@@ -1,24 +1,23 @@
 import numpy as np
 
+from matplotlib import cbook
 from matplotlib.tri import Triangulation
-import matplotlib._tri as _tri
 
 
-class TriFinder(object):
+class TriFinder:
     """
     Abstract base class for classes used to find the triangles of a
-    Triangulation in which (x,y) points lie.
+    Triangulation in which (x, y) points lie.
 
     Rather than instantiate an object of a class derived from TriFinder, it is
     usually better to use the function
     :func:`matplotlib.tri.Triangulation.get_trifinder`.
 
-    Derived classes implement __call__(x,y) where x,y are array_like point
+    Derived classes implement __call__(x, y) where x and y are array-like point
     coordinates of the same shape.
     """
     def __init__(self, triangulation):
-        if not isinstance(triangulation, Triangulation):
-            raise ValueError('Expected a Triangulation object')
+        cbook._check_isinstance(Triangulation, triangulation=triangulation)
         self._triangulation = triangulation
 
 
@@ -35,6 +34,7 @@ class TrapezoidMapTriFinder(TriFinder):
     this should not be relied upon.
     """
     def __init__(self, triangulation):
+        from matplotlib import _tri
         TriFinder.__init__(self, triangulation)
         self._cpp_trifinder = _tri.TrapezoidMapTriFinder(
             triangulation.get_cpp_triangulation())
@@ -43,10 +43,10 @@ class TrapezoidMapTriFinder(TriFinder):
     def __call__(self, x, y):
         """
         Return an array containing the indices of the triangles in which the
-        specified x,y points lie, or -1 for points that do not lie within a
-        triangle.
+        specified *x*, *y* points lie, or -1 for points that do not lie within
+        a triangle.
 
-        *x*, *y* are array_like x and y coordinates of the same shape and any
+        *x*, *y* are array-like x and y coordinates of the same shape and any
         number of dimensions.
 
         Returns integer array with the same shape and *x* and *y*.
